pub struct JsEditorApi {
pub plugin_name: String,
/* private fields */
}Expand description
JavaScript-exposed Editor API using rquickjs class system This allows proper lifetime handling for methods returning JS values
Fields
plugin_name: StringImplementations
Sourceimpl JsEditorApi
impl JsEditorApi
pub const js_get_active_buffer_id: __impl_get_active_buffer_id = __impl_get_active_buffer_id
pub const js_get_active_split_id: __impl_get_active_split_id = __impl_get_active_split_id
pub const js_list_buffers: __impl_list_buffers = __impl_list_buffers
pub const js_debug: __impl_debug = __impl_debug
pub const js_info: __impl_info = __impl_info
pub const js_warn: __impl_warn = __impl_warn
pub const js_error: __impl_error = __impl_error
pub const js_set_status: __impl_set_status = __impl_set_status
pub const js_copy_to_clipboard: __impl_copy_to_clipboard = __impl_copy_to_clipboard
pub const js_set_clipboard: __impl_set_clipboard = __impl_set_clipboard
pub const js_register_command: __impl_register_command = __impl_register_command
pub const js_unregister_command: __impl_unregister_command = __impl_unregister_command
pub const js_set_context: __impl_set_context = __impl_set_context
pub const js_execute_action: __impl_execute_action = __impl_execute_action
pub const js_t: __impl_t = __impl_t
pub const js_get_cursor_position: __impl_get_cursor_position = __impl_get_cursor_position
pub const js_get_buffer_path: __impl_get_buffer_path = __impl_get_buffer_path
pub const js_get_buffer_length: __impl_get_buffer_length = __impl_get_buffer_length
pub const js_is_buffer_modified: __impl_is_buffer_modified = __impl_is_buffer_modified
pub const js_save_buffer_to_path: __impl_save_buffer_to_path = __impl_save_buffer_to_path
pub const js_get_buffer_info: __impl_get_buffer_info = __impl_get_buffer_info
pub const js_get_primary_cursor: __impl_get_primary_cursor = __impl_get_primary_cursor
pub const js_get_all_cursors: __impl_get_all_cursors = __impl_get_all_cursors
pub const js_get_all_cursor_positions: __impl_get_all_cursor_positions = __impl_get_all_cursor_positions
pub const js_get_viewport: __impl_get_viewport = __impl_get_viewport
pub const js_get_cursor_line: __impl_get_cursor_line = __impl_get_cursor_line
pub const js_get_line_start_position_start: __impl_get_line_start_position_start = __impl_get_line_start_position_start
pub const js_get_line_end_position_start: __impl_get_line_end_position_start = __impl_get_line_end_position_start
pub const js_get_buffer_line_count_start: __impl_get_buffer_line_count_start = __impl_get_buffer_line_count_start
pub const js_scroll_to_line_center: __impl_scroll_to_line_center = __impl_scroll_to_line_center
pub const js_find_buffer_by_path: __impl_find_buffer_by_path = __impl_find_buffer_by_path
pub const js_get_buffer_saved_diff: __impl_get_buffer_saved_diff = __impl_get_buffer_saved_diff
pub const js_insert_text: __impl_insert_text = __impl_insert_text
pub const js_delete_range: __impl_delete_range = __impl_delete_range
pub const js_insert_at_cursor: __impl_insert_at_cursor = __impl_insert_at_cursor
pub const js_open_file: __impl_open_file = __impl_open_file
pub const js_open_file_in_split: __impl_open_file_in_split = __impl_open_file_in_split
pub const js_show_buffer: __impl_show_buffer = __impl_show_buffer
pub const js_close_buffer: __impl_close_buffer = __impl_close_buffer
pub const js_on: __impl_on = __impl_on
pub const js_off: __impl_off = __impl_off
pub const js_get_env: __impl_get_env = __impl_get_env
pub const js_get_cwd: __impl_get_cwd = __impl_get_cwd
pub const js_path_join: __impl_path_join = __impl_path_join
pub const js_path_dirname: __impl_path_dirname = __impl_path_dirname
pub const js_path_basename: __impl_path_basename = __impl_path_basename
pub const js_path_extname: __impl_path_extname = __impl_path_extname
pub const js_path_is_absolute: __impl_path_is_absolute = __impl_path_is_absolute
pub const js_file_exists: __impl_file_exists = __impl_file_exists
pub const js_read_file: __impl_read_file = __impl_read_file
pub const js_write_file: __impl_write_file = __impl_write_file
pub const js_read_dir: __impl_read_dir = __impl_read_dir
pub const js_get_config: __impl_get_config = __impl_get_config
pub const js_get_user_config: __impl_get_user_config = __impl_get_user_config
pub const js_reload_config: __impl_reload_config = __impl_reload_config
pub const js_reload_themes: __impl_reload_themes = __impl_reload_themes
pub const js_register_grammar: __impl_register_grammar = __impl_register_grammar
pub const js_register_language_config: __impl_register_language_config = __impl_register_language_config
pub const js_register_lsp_server: __impl_register_lsp_server = __impl_register_lsp_server
pub const js_reload_grammars: __impl_reload_grammars = __impl_reload_grammars
pub const js_get_config_dir: __impl_get_config_dir = __impl_get_config_dir
pub const js_get_themes_dir: __impl_get_themes_dir = __impl_get_themes_dir
pub const js_apply_theme: __impl_apply_theme = __impl_apply_theme
pub const js_get_theme_schema: __impl_get_theme_schema = __impl_get_theme_schema
pub const js_get_builtin_themes: __impl_get_builtin_themes = __impl_get_builtin_themes
pub const js_delete_theme_sync: __impl_delete_theme_sync = __impl_delete_theme_sync
pub const js_delete_theme: __impl_delete_theme = __impl_delete_theme
pub const js_file_stat: __impl_file_stat = __impl_file_stat
pub const js_is_process_running: __impl_is_process_running = __impl_is_process_running
pub const js_kill_process: __impl_kill_process = __impl_kill_process
pub const js_plugin_translate: __impl_plugin_translate = __impl_plugin_translate
pub const js_create_composite_buffer_start: __impl_create_composite_buffer_start = __impl_create_composite_buffer_start
pub const js_update_composite_alignment: __impl_update_composite_alignment = __impl_update_composite_alignment
pub const js_close_composite_buffer: __impl_close_composite_buffer = __impl_close_composite_buffer
pub const js_get_highlights_start: __impl_get_highlights_start = __impl_get_highlights_start
pub const js_add_overlay: __impl_add_overlay = __impl_add_overlay
pub const js_clear_namespace: __impl_clear_namespace = __impl_clear_namespace
pub const js_clear_all_overlays: __impl_clear_all_overlays = __impl_clear_all_overlays
pub const js_clear_overlays_in_range: __impl_clear_overlays_in_range = __impl_clear_overlays_in_range
pub const js_remove_overlay: __impl_remove_overlay = __impl_remove_overlay
pub const js_submit_view_transform: __impl_submit_view_transform = __impl_submit_view_transform
pub const js_clear_view_transform: __impl_clear_view_transform = __impl_clear_view_transform
pub const js_set_file_explorer_decorations: __impl_set_file_explorer_decorations = __impl_set_file_explorer_decorations
pub const js_clear_file_explorer_decorations: __impl_clear_file_explorer_decorations = __impl_clear_file_explorer_decorations
pub const js_add_virtual_text: __impl_add_virtual_text = __impl_add_virtual_text
pub const js_remove_virtual_text: __impl_remove_virtual_text = __impl_remove_virtual_text
pub const js_remove_virtual_texts_by_prefix: __impl_remove_virtual_texts_by_prefix = __impl_remove_virtual_texts_by_prefix
pub const js_clear_virtual_texts: __impl_clear_virtual_texts = __impl_clear_virtual_texts
pub const js_clear_virtual_text_namespace: __impl_clear_virtual_text_namespace = __impl_clear_virtual_text_namespace
pub const js_add_virtual_line: __impl_add_virtual_line = __impl_add_virtual_line
pub const js_prompt_start: __impl_prompt_start = __impl_prompt_start
pub const js_start_prompt: __impl_start_prompt = __impl_start_prompt
pub const js_start_prompt_with_initial: __impl_start_prompt_with_initial = __impl_start_prompt_with_initial
pub const js_set_prompt_suggestions: __impl_set_prompt_suggestions = __impl_set_prompt_suggestions
pub const js_define_mode: __impl_define_mode = __impl_define_mode
pub const js_set_editor_mode: __impl_set_editor_mode = __impl_set_editor_mode
pub const js_get_editor_mode: __impl_get_editor_mode = __impl_get_editor_mode
pub const js_close_split: __impl_close_split = __impl_close_split
pub const js_set_split_buffer: __impl_set_split_buffer = __impl_set_split_buffer
pub const js_focus_split: __impl_focus_split = __impl_focus_split
pub const js_set_split_scroll: __impl_set_split_scroll = __impl_set_split_scroll
pub const js_set_split_ratio: __impl_set_split_ratio = __impl_set_split_ratio
pub const js_distribute_splits_evenly: __impl_distribute_splits_evenly = __impl_distribute_splits_evenly
pub const js_set_buffer_cursor: __impl_set_buffer_cursor = __impl_set_buffer_cursor
pub const js_set_line_indicator: __impl_set_line_indicator = __impl_set_line_indicator
pub const js_clear_line_indicators: __impl_clear_line_indicators = __impl_clear_line_indicators
pub const js_set_line_numbers: __impl_set_line_numbers = __impl_set_line_numbers
pub const js_set_line_wrap: __impl_set_line_wrap = __impl_set_line_wrap
pub const js_create_scroll_sync_group: __impl_create_scroll_sync_group = __impl_create_scroll_sync_group
pub const js_set_scroll_sync_anchors: __impl_set_scroll_sync_anchors = __impl_set_scroll_sync_anchors
pub const js_remove_scroll_sync_group: __impl_remove_scroll_sync_group = __impl_remove_scroll_sync_group
pub const js_execute_actions: __impl_execute_actions = __impl_execute_actions
pub const js_show_action_popup: __impl_show_action_popup = __impl_show_action_popup
pub const js_disable_lsp_for_language: __impl_disable_lsp_for_language = __impl_disable_lsp_for_language
pub const js_set_lsp_root_uri: __impl_set_lsp_root_uri = __impl_set_lsp_root_uri
pub const js_get_all_diagnostics: __impl_get_all_diagnostics = __impl_get_all_diagnostics
pub const js_get_handlers: __impl_get_handlers = __impl_get_handlers
pub const js_create_virtual_buffer_start: __impl_create_virtual_buffer_start = __impl_create_virtual_buffer_start
pub const js_create_virtual_buffer_in_split_start: __impl_create_virtual_buffer_in_split_start = __impl_create_virtual_buffer_in_split_start
pub const js_create_virtual_buffer_in_existing_split_start: __impl_create_virtual_buffer_in_existing_split_start = __impl_create_virtual_buffer_in_existing_split_start
pub const js_set_virtual_buffer_content: __impl_set_virtual_buffer_content = __impl_set_virtual_buffer_content
pub const js_get_text_properties_at_cursor: __impl_get_text_properties_at_cursor = __impl_get_text_properties_at_cursor
pub const js_spawn_process_start: __impl_spawn_process_start = __impl_spawn_process_start
pub const js_spawn_process_wait_start: __impl_spawn_process_wait_start = __impl_spawn_process_wait_start
pub const js_get_buffer_text_start: __impl_get_buffer_text_start = __impl_get_buffer_text_start
pub const js_delay_start: __impl_delay_start = __impl_delay_start
pub const js_send_lsp_request_start: __impl_send_lsp_request_start = __impl_send_lsp_request_start
pub const js_spawn_background_process_start: __impl_spawn_background_process_start = __impl_spawn_background_process_start
pub const js_kill_background_process: __impl_kill_background_process = __impl_kill_background_process
pub const js_refresh_lines: __impl_refresh_lines = __impl_refresh_lines
pub const js_get_current_locale: __impl_get_current_locale = __impl_get_current_locale
pub const js_load_plugin_start: __impl_load_plugin_start = __impl_load_plugin_start
pub const js_unload_plugin_start: __impl_unload_plugin_start = __impl_unload_plugin_start
pub const js_reload_plugin_start: __impl_reload_plugin_start = __impl_reload_plugin_start
pub const js_list_plugins_start: __impl_list_plugins_start = __impl_list_plugins_start
Sourceimpl JsEditorApi
impl JsEditorApi
Sourcepub fn get_active_buffer_id(&self) -> u32
pub fn get_active_buffer_id(&self) -> u32
Get the active buffer ID (0 if none)
Sourcepub fn get_active_split_id(&self) -> u32
pub fn get_active_split_id(&self) -> u32
Get the active split ID
Sourcepub fn list_buffers<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn list_buffers<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
List all open buffers - returns array of BufferInfo objects
pub fn debug(&self, msg: String)
pub fn info(&self, msg: String)
pub fn warn(&self, msg: String)
pub fn error(&self, msg: String)
pub fn set_status(&self, msg: String)
pub fn copy_to_clipboard(&self, text: String)
pub fn set_clipboard(&self, text: String)
Sourcepub fn register_command<'js>(
&self,
_ctx: Ctx<'js>,
name: String,
description: String,
handler_name: String,
context: Opt<Value<'js>>,
) -> Result<bool>
pub fn register_command<'js>( &self, _ctx: Ctx<'js>, name: String, description: String, handler_name: String, context: Opt<Value<'js>>, ) -> Result<bool>
Register a command - reads plugin name from pluginName global context is optional - can be omitted, null, undefined, or a string
Sourcepub fn unregister_command(&self, name: String) -> bool
pub fn unregister_command(&self, name: String) -> bool
Unregister a command by name
Sourcepub fn set_context(&self, name: String, active: bool) -> bool
pub fn set_context(&self, name: String, active: bool) -> bool
Set a context (for keybinding conditions)
Sourcepub fn execute_action(&self, action_name: String) -> bool
pub fn execute_action(&self, action_name: String) -> bool
Execute a built-in action
Sourcepub fn t<'js>(
&self,
_ctx: Ctx<'js>,
key: String,
args: Rest<Value<'js>>,
) -> String
pub fn t<'js>( &self, _ctx: Ctx<'js>, key: String, args: Rest<Value<'js>>, ) -> String
Translate a string - reads plugin name from pluginName global Args is optional - can be omitted, undefined, null, or an object
Sourcepub fn get_cursor_position(&self) -> u32
pub fn get_cursor_position(&self) -> u32
Get cursor position in active buffer
Sourcepub fn get_buffer_path(&self, buffer_id: u32) -> String
pub fn get_buffer_path(&self, buffer_id: u32) -> String
Get file path for a buffer
Sourcepub fn get_buffer_length(&self, buffer_id: u32) -> u32
pub fn get_buffer_length(&self, buffer_id: u32) -> u32
Get buffer length in bytes
Sourcepub fn is_buffer_modified(&self, buffer_id: u32) -> bool
pub fn is_buffer_modified(&self, buffer_id: u32) -> bool
Check if buffer has unsaved changes
Sourcepub fn save_buffer_to_path(&self, buffer_id: u32, path: String) -> bool
pub fn save_buffer_to_path(&self, buffer_id: u32, path: String) -> bool
Save a buffer to a specific file path Used by :w filename to save unnamed buffers or save-as
Sourcepub fn get_buffer_info<'js>(
&self,
ctx: Ctx<'js>,
buffer_id: u32,
) -> Result<Value<'js>>
pub fn get_buffer_info<'js>( &self, ctx: Ctx<'js>, buffer_id: u32, ) -> Result<Value<'js>>
Get buffer info by ID
Sourcepub fn get_primary_cursor<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn get_primary_cursor<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
Get primary cursor info for active buffer
Sourcepub fn get_all_cursors<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn get_all_cursors<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
Get all cursors for active buffer
Sourcepub fn get_all_cursor_positions<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn get_all_cursor_positions<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
Get all cursor positions as byte offsets
Sourcepub fn get_viewport<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn get_viewport<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
Get viewport info for active buffer
Sourcepub fn get_cursor_line(&self) -> u32
pub fn get_cursor_line(&self) -> u32
Get the line number (0-indexed) of the primary cursor
Sourcepub fn get_line_start_position_start(&self, _ctx: Ctx<'_>, line: u32) -> u64
pub fn get_line_start_position_start(&self, _ctx: Ctx<'_>, line: u32) -> u64
Get the byte offset of the start of a line (0-indexed line number) Returns null if the line number is out of range
Sourcepub fn get_line_end_position_start(&self, _ctx: Ctx<'_>, line: u32) -> u64
pub fn get_line_end_position_start(&self, _ctx: Ctx<'_>, line: u32) -> u64
Get the byte offset of the end of a line (0-indexed line number) Returns the position after the last character of the line (before newline) Returns null if the line number is out of range
Sourcepub fn get_buffer_line_count_start(&self, _ctx: Ctx<'_>) -> u64
pub fn get_buffer_line_count_start(&self, _ctx: Ctx<'_>) -> u64
Get the total number of lines in the active buffer Returns null if buffer not found
Sourcepub fn scroll_to_line_center(
&self,
split_id: u32,
buffer_id: u32,
line: u32,
) -> bool
pub fn scroll_to_line_center( &self, split_id: u32, buffer_id: u32, line: u32, ) -> bool
Scroll a split to center a specific line in the viewport Line is 0-indexed (0 = first line)
Sourcepub fn find_buffer_by_path(&self, path: String) -> u32
pub fn find_buffer_by_path(&self, path: String) -> u32
Find buffer by file path, returns buffer ID or 0 if not found
Sourcepub fn get_buffer_saved_diff<'js>(
&self,
ctx: Ctx<'js>,
buffer_id: u32,
) -> Result<Value<'js>>
pub fn get_buffer_saved_diff<'js>( &self, ctx: Ctx<'js>, buffer_id: u32, ) -> Result<Value<'js>>
Get diff between buffer content and last saved version
Sourcepub fn insert_text(&self, buffer_id: u32, position: u32, text: String) -> bool
pub fn insert_text(&self, buffer_id: u32, position: u32, text: String) -> bool
Insert text at a position in a buffer
Sourcepub fn delete_range(&self, buffer_id: u32, start: u32, end: u32) -> bool
pub fn delete_range(&self, buffer_id: u32, start: u32, end: u32) -> bool
Delete a range from a buffer
Sourcepub fn insert_at_cursor(&self, text: String) -> bool
pub fn insert_at_cursor(&self, text: String) -> bool
Insert text at cursor position in active buffer
Sourcepub fn open_file(
&self,
path: String,
line: Option<u32>,
column: Option<u32>,
) -> bool
pub fn open_file( &self, path: String, line: Option<u32>, column: Option<u32>, ) -> bool
Open a file, optionally at a specific line/column
Sourcepub fn open_file_in_split(
&self,
split_id: u32,
path: String,
line: u32,
column: u32,
) -> bool
pub fn open_file_in_split( &self, split_id: u32, path: String, line: u32, column: u32, ) -> bool
Open a file in a specific split
Sourcepub fn show_buffer(&self, buffer_id: u32) -> bool
pub fn show_buffer(&self, buffer_id: u32) -> bool
Show a buffer in the current split
Sourcepub fn close_buffer(&self, buffer_id: u32) -> bool
pub fn close_buffer(&self, buffer_id: u32) -> bool
Close a buffer
Sourcepub fn on<'js>(&self, _ctx: Ctx<'js>, event_name: String, handler_name: String)
pub fn on<'js>(&self, _ctx: Ctx<'js>, event_name: String, handler_name: String)
Subscribe to an editor event
Sourcepub fn path_join(&self, parts: Rest<String>) -> String
pub fn path_join(&self, parts: Rest<String>) -> String
Join path components (variadic - accepts multiple string arguments) Always uses forward slashes for cross-platform consistency (like Node.js path.posix.join)
Sourcepub fn path_dirname(&self, path: String) -> String
pub fn path_dirname(&self, path: String) -> String
Get directory name from path
Sourcepub fn path_basename(&self, path: String) -> String
pub fn path_basename(&self, path: String) -> String
Get file name from path
Sourcepub fn path_extname(&self, path: String) -> String
pub fn path_extname(&self, path: String) -> String
Get file extension
Sourcepub fn path_is_absolute(&self, path: String) -> bool
pub fn path_is_absolute(&self, path: String) -> bool
Check if path is absolute
Sourcepub fn file_exists(&self, path: String) -> bool
pub fn file_exists(&self, path: String) -> bool
Check if file exists
Sourcepub fn write_file(&self, path: String, content: String) -> bool
pub fn write_file(&self, path: String, content: String) -> bool
Write file contents
Sourcepub fn read_dir<'js>(&self, ctx: Ctx<'js>, path: String) -> Result<Value<'js>>
pub fn read_dir<'js>(&self, ctx: Ctx<'js>, path: String) -> Result<Value<'js>>
Read directory contents (returns array of {name, is_file, is_dir})
Sourcepub fn get_config<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn get_config<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
Get current config as JS object
Sourcepub fn get_user_config<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn get_user_config<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
Get user config as JS object
Sourcepub fn reload_config(&self)
pub fn reload_config(&self)
Reload configuration from file
Sourcepub fn reload_themes(&self)
pub fn reload_themes(&self)
Reload theme registry from disk Call this after installing theme packages or saving new themes
Sourcepub fn register_grammar(
&self,
language: String,
grammar_path: String,
extensions: Vec<String>,
) -> bool
pub fn register_grammar( &self, language: String, grammar_path: String, extensions: Vec<String>, ) -> bool
Register a TextMate grammar file for a language The grammar will be pending until reload_grammars() is called
Sourcepub fn register_language_config(
&self,
language: String,
config: LanguagePackConfig,
) -> bool
pub fn register_language_config( &self, language: String, config: LanguagePackConfig, ) -> bool
Register language configuration (comment prefix, indentation, formatter)
Sourcepub fn register_lsp_server(
&self,
language: String,
config: LspServerPackConfig,
) -> bool
pub fn register_lsp_server( &self, language: String, config: LspServerPackConfig, ) -> bool
Register an LSP server for a language
Sourcepub fn reload_grammars(&self)
pub fn reload_grammars(&self)
Reload the grammar registry to apply registered grammars Call this after registering one or more grammars
Sourcepub fn get_config_dir(&self) -> String
pub fn get_config_dir(&self) -> String
Get config directory path
Sourcepub fn get_themes_dir(&self) -> String
pub fn get_themes_dir(&self) -> String
Get themes directory path
Sourcepub fn apply_theme(&self, theme_name: String) -> bool
pub fn apply_theme(&self, theme_name: String) -> bool
Apply a theme by name
Sourcepub fn get_theme_schema<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn get_theme_schema<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
Get theme schema as JS object
Sourcepub fn get_builtin_themes<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn get_builtin_themes<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
Get list of builtin themes as JS object
Sourcepub fn delete_theme_sync(&self, name: String) -> bool
pub fn delete_theme_sync(&self, name: String) -> bool
Delete a custom theme file (sync)
Sourcepub fn delete_theme(&self, name: String) -> bool
pub fn delete_theme(&self, name: String) -> bool
Delete a custom theme (alias for deleteThemeSync)
Sourcepub fn file_stat<'js>(&self, ctx: Ctx<'js>, path: String) -> Result<Value<'js>>
pub fn file_stat<'js>(&self, ctx: Ctx<'js>, path: String) -> Result<Value<'js>>
Get file stat information
Sourcepub fn is_process_running(&self, _process_id: u64) -> bool
pub fn is_process_running(&self, _process_id: u64) -> bool
Check if a background process is still running
Sourcepub fn kill_process(&self, process_id: u64) -> bool
pub fn kill_process(&self, process_id: u64) -> bool
Kill a process by ID (alias for killBackgroundProcess)
Sourcepub fn plugin_translate<'js>(
&self,
_ctx: Ctx<'js>,
plugin_name: String,
key: String,
args: Opt<Object<'js>>,
) -> String
pub fn plugin_translate<'js>( &self, _ctx: Ctx<'js>, plugin_name: String, key: String, args: Opt<Object<'js>>, ) -> String
Translate a key for a specific plugin
Sourcepub fn create_composite_buffer_start(
&self,
opts: CreateCompositeBufferOptions,
) -> u64
pub fn create_composite_buffer_start( &self, opts: CreateCompositeBufferOptions, ) -> u64
Create a composite buffer (async)
Uses typed CreateCompositeBufferOptions - serde validates field names at runtime
via deny_unknown_fields attribute
Sourcepub fn update_composite_alignment(
&self,
buffer_id: u32,
hunks: Vec<CompositeHunk>,
) -> bool
pub fn update_composite_alignment( &self, buffer_id: u32, hunks: Vec<CompositeHunk>, ) -> bool
Update alignment hunks for a composite buffer
Uses typed Vec
Sourcepub fn close_composite_buffer(&self, buffer_id: u32) -> bool
pub fn close_composite_buffer(&self, buffer_id: u32) -> bool
Close a composite buffer
Sourcepub fn get_highlights_start<'js>(
&self,
_ctx: Ctx<'js>,
buffer_id: u32,
start: u32,
end: u32,
) -> Result<u64>
pub fn get_highlights_start<'js>( &self, _ctx: Ctx<'js>, buffer_id: u32, start: u32, end: u32, ) -> Result<u64>
Request syntax highlights for a buffer range (async)
Sourcepub fn add_overlay<'js>(
&self,
_ctx: Ctx<'js>,
buffer_id: u32,
namespace: String,
start: u32,
end: u32,
options: Object<'js>,
) -> Result<bool>
pub fn add_overlay<'js>( &self, _ctx: Ctx<'js>, buffer_id: u32, namespace: String, start: u32, end: u32, options: Object<'js>, ) -> Result<bool>
Add an overlay with styling options
Colors can be specified as RGB arrays [r, g, b] or theme key strings.
Theme keys are resolved at render time, so overlays update with theme changes.
Theme key examples: “ui.status_bar_fg”, “editor.selection_bg”, “syntax.keyword”
Example usage in TypeScript:
editor.addOverlay(bufferId, "my-namespace", 0, 10, {
fg: "syntax.keyword", // theme key
bg: [40, 40, 50], // RGB array
bold: true,
});Sourcepub fn clear_namespace(&self, buffer_id: u32, namespace: String) -> bool
pub fn clear_namespace(&self, buffer_id: u32, namespace: String) -> bool
Clear all overlays in a namespace
Sourcepub fn clear_all_overlays(&self, buffer_id: u32) -> bool
pub fn clear_all_overlays(&self, buffer_id: u32) -> bool
Clear all overlays from a buffer
Sourcepub fn clear_overlays_in_range(
&self,
buffer_id: u32,
start: u32,
end: u32,
) -> bool
pub fn clear_overlays_in_range( &self, buffer_id: u32, start: u32, end: u32, ) -> bool
Clear all overlays that overlap with a byte range
Sourcepub fn remove_overlay(&self, buffer_id: u32, handle: String) -> bool
pub fn remove_overlay(&self, buffer_id: u32, handle: String) -> bool
Remove an overlay by its handle
Sourcepub fn submit_view_transform<'js>(
&self,
_ctx: Ctx<'js>,
buffer_id: u32,
split_id: Option<u32>,
start: u32,
end: u32,
tokens: Vec<Object<'js>>,
layout_hints: Opt<Object<'js>>,
) -> Result<bool>
pub fn submit_view_transform<'js>( &self, _ctx: Ctx<'js>, buffer_id: u32, split_id: Option<u32>, start: u32, end: u32, tokens: Vec<Object<'js>>, layout_hints: Opt<Object<'js>>, ) -> Result<bool>
Submit a view transform for a buffer/split
Accepts tokens in the simple format: {kind: “text”|“newline”|“space”|“break”, text: “…”, sourceOffset: N, style?: {…}}
Also accepts the TypeScript-defined format for backwards compatibility: {kind: {Text: “…”} | “Newline” | “Space” | “Break”, source_offset: N, style?: {…}}
Sourcepub fn clear_view_transform(
&self,
buffer_id: u32,
split_id: Option<u32>,
) -> bool
pub fn clear_view_transform( &self, buffer_id: u32, split_id: Option<u32>, ) -> bool
Clear view transform for a buffer/split
Sourcepub fn set_file_explorer_decorations<'js>(
&self,
_ctx: Ctx<'js>,
namespace: String,
decorations: Vec<Object<'js>>,
) -> Result<bool>
pub fn set_file_explorer_decorations<'js>( &self, _ctx: Ctx<'js>, namespace: String, decorations: Vec<Object<'js>>, ) -> Result<bool>
Set file explorer decorations for a namespace
Sourcepub fn clear_file_explorer_decorations(&self, namespace: String) -> bool
pub fn clear_file_explorer_decorations(&self, namespace: String) -> bool
Clear file explorer decorations for a namespace
Sourcepub fn add_virtual_text(
&self,
buffer_id: u32,
virtual_text_id: String,
position: u32,
text: String,
r: u8,
g: u8,
b: u8,
before: bool,
use_bg: bool,
) -> bool
pub fn add_virtual_text( &self, buffer_id: u32, virtual_text_id: String, position: u32, text: String, r: u8, g: u8, b: u8, before: bool, use_bg: bool, ) -> bool
Add virtual text (inline text that doesn’t exist in the buffer)
Sourcepub fn remove_virtual_text(
&self,
buffer_id: u32,
virtual_text_id: String,
) -> bool
pub fn remove_virtual_text( &self, buffer_id: u32, virtual_text_id: String, ) -> bool
Remove a virtual text by ID
Sourcepub fn remove_virtual_texts_by_prefix(
&self,
buffer_id: u32,
prefix: String,
) -> bool
pub fn remove_virtual_texts_by_prefix( &self, buffer_id: u32, prefix: String, ) -> bool
Remove virtual texts whose ID starts with the given prefix
Sourcepub fn clear_virtual_texts(&self, buffer_id: u32) -> bool
pub fn clear_virtual_texts(&self, buffer_id: u32) -> bool
Clear all virtual texts from a buffer
Sourcepub fn clear_virtual_text_namespace(
&self,
buffer_id: u32,
namespace: String,
) -> bool
pub fn clear_virtual_text_namespace( &self, buffer_id: u32, namespace: String, ) -> bool
Clear all virtual texts in a namespace
Sourcepub fn add_virtual_line(
&self,
buffer_id: u32,
position: u32,
text: String,
fg_r: u8,
fg_g: u8,
fg_b: u8,
bg_r: u8,
bg_g: u8,
bg_b: u8,
above: bool,
namespace: String,
priority: i32,
) -> bool
pub fn add_virtual_line( &self, buffer_id: u32, position: u32, text: String, fg_r: u8, fg_g: u8, fg_b: u8, bg_r: u8, bg_g: u8, bg_b: u8, above: bool, namespace: String, priority: i32, ) -> bool
Add a virtual line (full line above/below a position)
Sourcepub fn prompt_start(
&self,
_ctx: Ctx<'_>,
label: String,
initial_value: String,
) -> u64
pub fn prompt_start( &self, _ctx: Ctx<'_>, label: String, initial_value: String, ) -> u64
Show a prompt and wait for user input (async) Returns the user input or null if cancelled
Sourcepub fn start_prompt(&self, label: String, prompt_type: String) -> bool
pub fn start_prompt(&self, label: String, prompt_type: String) -> bool
Start an interactive prompt
Sourcepub fn start_prompt_with_initial(
&self,
label: String,
prompt_type: String,
initial_value: String,
) -> bool
pub fn start_prompt_with_initial( &self, label: String, prompt_type: String, initial_value: String, ) -> bool
Start a prompt with initial value
Sourcepub fn set_prompt_suggestions(&self, suggestions: Vec<Suggestion>) -> bool
pub fn set_prompt_suggestions(&self, suggestions: Vec<Suggestion>) -> bool
Set suggestions for the current prompt
Uses typed Vec
Sourcepub fn define_mode(
&self,
name: String,
parent: Option<String>,
bindings_arr: Vec<Vec<String>>,
read_only: Opt<bool>,
) -> bool
pub fn define_mode( &self, name: String, parent: Option<String>, bindings_arr: Vec<Vec<String>>, read_only: Opt<bool>, ) -> bool
Define a buffer mode (takes bindings as array of [key, command] pairs)
Sourcepub fn set_editor_mode(&self, mode: Option<String>) -> bool
pub fn set_editor_mode(&self, mode: Option<String>) -> bool
Set the global editor mode
Sourcepub fn get_editor_mode(&self) -> Option<String>
pub fn get_editor_mode(&self) -> Option<String>
Get the current editor mode
Sourcepub fn close_split(&self, split_id: u32) -> bool
pub fn close_split(&self, split_id: u32) -> bool
Close a split
Sourcepub fn set_split_buffer(&self, split_id: u32, buffer_id: u32) -> bool
pub fn set_split_buffer(&self, split_id: u32, buffer_id: u32) -> bool
Set the buffer displayed in a split
Sourcepub fn focus_split(&self, split_id: u32) -> bool
pub fn focus_split(&self, split_id: u32) -> bool
Focus a specific split
Sourcepub fn set_split_scroll(&self, split_id: u32, top_byte: u32) -> bool
pub fn set_split_scroll(&self, split_id: u32, top_byte: u32) -> bool
Set scroll position of a split
Sourcepub fn set_split_ratio(&self, split_id: u32, ratio: f32) -> bool
pub fn set_split_ratio(&self, split_id: u32, ratio: f32) -> bool
Set the ratio of a split (0.0 to 1.0, 0.5 = equal)
Sourcepub fn distribute_splits_evenly(&self) -> bool
pub fn distribute_splits_evenly(&self) -> bool
Distribute all splits evenly
Sourcepub fn set_buffer_cursor(&self, buffer_id: u32, position: u32) -> bool
pub fn set_buffer_cursor(&self, buffer_id: u32, position: u32) -> bool
Set cursor position in a buffer
Sourcepub fn set_line_indicator(
&self,
buffer_id: u32,
line: u32,
namespace: String,
symbol: String,
r: u8,
g: u8,
b: u8,
priority: i32,
) -> bool
pub fn set_line_indicator( &self, buffer_id: u32, line: u32, namespace: String, symbol: String, r: u8, g: u8, b: u8, priority: i32, ) -> bool
Set a line indicator in the gutter
Sourcepub fn clear_line_indicators(&self, buffer_id: u32, namespace: String) -> bool
pub fn clear_line_indicators(&self, buffer_id: u32, namespace: String) -> bool
Clear line indicators in a namespace
Sourcepub fn set_line_numbers(&self, buffer_id: u32, enabled: bool) -> bool
pub fn set_line_numbers(&self, buffer_id: u32, enabled: bool) -> bool
Enable or disable line numbers for a buffer
Sourcepub fn set_line_wrap(
&self,
buffer_id: u32,
split_id: Option<u32>,
enabled: bool,
) -> bool
pub fn set_line_wrap( &self, buffer_id: u32, split_id: Option<u32>, enabled: bool, ) -> bool
Enable or disable line wrapping for a buffer/split
Sourcepub fn create_scroll_sync_group(
&self,
group_id: u32,
left_split: u32,
right_split: u32,
) -> bool
pub fn create_scroll_sync_group( &self, group_id: u32, left_split: u32, right_split: u32, ) -> bool
Create a scroll sync group for anchor-based synchronized scrolling
Sourcepub fn set_scroll_sync_anchors<'js>(
&self,
_ctx: Ctx<'js>,
group_id: u32,
anchors: Vec<Vec<u32>>,
) -> bool
pub fn set_scroll_sync_anchors<'js>( &self, _ctx: Ctx<'js>, group_id: u32, anchors: Vec<Vec<u32>>, ) -> bool
Set sync anchors for a scroll sync group
Sourcepub fn remove_scroll_sync_group(&self, group_id: u32) -> bool
pub fn remove_scroll_sync_group(&self, group_id: u32) -> bool
Remove a scroll sync group
Sourcepub fn execute_actions(&self, actions: Vec<ActionSpec>) -> bool
pub fn execute_actions(&self, actions: Vec<ActionSpec>) -> bool
Execute multiple actions in sequence
Takes typed ActionSpec array - serde validates field names at runtime
Sourcepub fn show_action_popup(&self, opts: ActionPopupOptions) -> bool
pub fn show_action_popup(&self, opts: ActionPopupOptions) -> bool
Show an action popup
Takes a typed ActionPopupOptions struct - serde validates field names at runtime
Sourcepub fn disable_lsp_for_language(&self, language: String) -> bool
pub fn disable_lsp_for_language(&self, language: String) -> bool
Disable LSP for a specific language
Sourcepub fn set_lsp_root_uri(&self, language: String, uri: String) -> bool
pub fn set_lsp_root_uri(&self, language: String, uri: String) -> bool
Set the workspace root URI for a specific language’s LSP server This allows plugins to specify project roots (e.g., directory containing .csproj)
Sourcepub fn get_all_diagnostics<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
pub fn get_all_diagnostics<'js>(&self, ctx: Ctx<'js>) -> Result<Value<'js>>
Get all diagnostics from LSP
Sourcepub fn get_handlers(&self, event_name: String) -> Vec<String>
pub fn get_handlers(&self, event_name: String) -> Vec<String>
Get registered event handlers for an event
Sourcepub fn create_virtual_buffer_start(
&self,
_ctx: Ctx<'_>,
opts: CreateVirtualBufferOptions,
) -> Result<u64>
pub fn create_virtual_buffer_start( &self, _ctx: Ctx<'_>, opts: CreateVirtualBufferOptions, ) -> Result<u64>
Create a virtual buffer in current split (async, returns buffer and split IDs)
Sourcepub fn create_virtual_buffer_in_split_start(
&self,
_ctx: Ctx<'_>,
opts: CreateVirtualBufferInSplitOptions,
) -> Result<u64>
pub fn create_virtual_buffer_in_split_start( &self, _ctx: Ctx<'_>, opts: CreateVirtualBufferInSplitOptions, ) -> Result<u64>
Create a virtual buffer in a new split (async, returns buffer and split IDs)
Sourcepub fn create_virtual_buffer_in_existing_split_start(
&self,
_ctx: Ctx<'_>,
opts: CreateVirtualBufferInExistingSplitOptions,
) -> Result<u64>
pub fn create_virtual_buffer_in_existing_split_start( &self, _ctx: Ctx<'_>, opts: CreateVirtualBufferInExistingSplitOptions, ) -> Result<u64>
Create a virtual buffer in an existing split (async, returns buffer and split IDs)
Sourcepub fn set_virtual_buffer_content<'js>(
&self,
ctx: Ctx<'js>,
buffer_id: u32,
entries_arr: Vec<Object<'js>>,
) -> Result<bool>
pub fn set_virtual_buffer_content<'js>( &self, ctx: Ctx<'js>, buffer_id: u32, entries_arr: Vec<Object<'js>>, ) -> Result<bool>
Set virtual buffer content (takes array of entry objects)
Note: entries should be TextPropertyEntry[] - uses manual parsing for HashMap support
Sourcepub fn get_text_properties_at_cursor(
&self,
buffer_id: u32,
) -> TextPropertiesAtCursor
pub fn get_text_properties_at_cursor( &self, buffer_id: u32, ) -> TextPropertiesAtCursor
Get text properties at cursor position (returns JS array)
Sourcepub fn spawn_process_start(
&self,
_ctx: Ctx<'_>,
command: String,
args: Vec<String>,
cwd: Opt<String>,
) -> u64
pub fn spawn_process_start( &self, _ctx: Ctx<'_>, command: String, args: Vec<String>, cwd: Opt<String>, ) -> u64
Spawn a process (async, returns request_id)
Sourcepub fn spawn_process_wait_start(&self, _ctx: Ctx<'_>, process_id: u64) -> u64
pub fn spawn_process_wait_start(&self, _ctx: Ctx<'_>, process_id: u64) -> u64
Wait for a process to complete and get its result (async)
Sourcepub fn get_buffer_text_start(
&self,
_ctx: Ctx<'_>,
buffer_id: u32,
start: u32,
end: u32,
) -> u64
pub fn get_buffer_text_start( &self, _ctx: Ctx<'_>, buffer_id: u32, start: u32, end: u32, ) -> u64
Get buffer text range (async, returns request_id)
Sourcepub fn delay_start(&self, _ctx: Ctx<'_>, duration_ms: u64) -> u64
pub fn delay_start(&self, _ctx: Ctx<'_>, duration_ms: u64) -> u64
Delay/sleep (async, returns request_id)
Sourcepub fn send_lsp_request_start<'js>(
&self,
ctx: Ctx<'js>,
language: String,
method: String,
params: Option<Object<'js>>,
) -> Result<u64>
pub fn send_lsp_request_start<'js>( &self, ctx: Ctx<'js>, language: String, method: String, params: Option<Object<'js>>, ) -> Result<u64>
Send LSP request (async, returns request_id)
Sourcepub fn spawn_background_process_start(
&self,
_ctx: Ctx<'_>,
command: String,
args: Vec<String>,
cwd: Opt<String>,
) -> u64
pub fn spawn_background_process_start( &self, _ctx: Ctx<'_>, command: String, args: Vec<String>, cwd: Opt<String>, ) -> u64
Spawn a background process (async, returns request_id which is also process_id)
Sourcepub fn kill_background_process(&self, process_id: u64) -> bool
pub fn kill_background_process(&self, process_id: u64) -> bool
Kill a background process
Sourcepub fn refresh_lines(&self, buffer_id: u32) -> bool
pub fn refresh_lines(&self, buffer_id: u32) -> bool
Force refresh of line display
Sourcepub fn get_current_locale(&self) -> String
pub fn get_current_locale(&self) -> String
Get the current locale
Sourcepub fn load_plugin_start(&self, _ctx: Ctx<'_>, path: String) -> u64
pub fn load_plugin_start(&self, _ctx: Ctx<'_>, path: String) -> u64
Load a plugin from a file path (async)
Sourcepub fn unload_plugin_start(&self, _ctx: Ctx<'_>, name: String) -> u64
pub fn unload_plugin_start(&self, _ctx: Ctx<'_>, name: String) -> u64
Unload a plugin by name (async)
Sourcepub fn reload_plugin_start(&self, _ctx: Ctx<'_>, name: String) -> u64
pub fn reload_plugin_start(&self, _ctx: Ctx<'_>, name: String) -> u64
Reload a plugin by name (async)
Sourcepub fn list_plugins_start(&self, _ctx: Ctx<'_>) -> u64
pub fn list_plugins_start(&self, _ctx: Ctx<'_>) -> u64
List all loaded plugins (async) Returns array of { name: string, path: string, enabled: boolean }